@@ -143,3 +143,54 @@ class TestGenericLocalLinkConnectionHook(test_base.NodeTest):
         ]
         self.hook.before_update(self.data, self.node_info)
         self.assertCalledWithPatch(patches, mock_patch)
+
+    @mock.patch.object(node_cache.NodeInfo, 'patch_port')
+    def test_processed_data_available(self, mock_patch):
+        self.data['all_interfaces'] = {
+            'em1': {"ip": self.ips[0], "mac": self.macs[0],
+                    "lldp_processed": {
+                        "switch_chassis_id": "11:22:33:aa:bb:dd",
+                        "switch_port_id": "Ethernet2/66"}
+                    }
+        }
+
+        patches = [
+            {'path': '/local_link_connection/port_id',
+             'value': 'Ethernet2/66', 'op': 'add'},
+            {'path': '/local_link_connection/switch_id',
+             'value': '11:22:33:aa:bb:dd', 'op': 'add'},
+        ]
+        self.hook.before_update(self.data, self.node_info)
+        self.assertCalledWithPatch(patches, mock_patch)
+
+    @mock.patch.object(node_cache.NodeInfo, 'patch_port')
+    def test_processed_data_chassis_only(self, mock_patch):
+        self.data['all_interfaces'] = {
+            'em1': {"ip": self.ips[0], "mac": self.macs[0],
+                    "lldp_processed": {
+                        "switch_chassis_id": "11:22:33:aa:bb:dd"}
+                    }
+        }
+
+        patches = [
+            {'path': '/local_link_connection/switch_id',
+             'value': '11:22:33:aa:bb:dd', 'op': 'add'}
+        ]
+        self.hook.before_update(self.data, self.node_info)
+        self.assertCalledWithPatch(patches, mock_patch)
+
+    @mock.patch.object(node_cache.NodeInfo, 'patch_port')
+    def test_processed_data_port_only(self, mock_patch):
+        self.data['all_interfaces'] = {
+            'em1': {"ip": self.ips[0], "mac": self.macs[0],
+                    "lldp_processed": {
+                        "switch_port_id": "Ethernet2/66"}
+                    }
+        }
+
+        patches = [
+            {'path': '/local_link_connection/port_id',
+             'value': 'Ethernet2/66', 'op': 'add'}
+        ]
+        self.hook.before_update(self.data, self.node_info)
+        self.assertCalledWithPatch(patches, mock_patch)
